@@ -200,14 +200,15 @@ void Capture::checkCCD(int ccdNum)
         int x,y,w,h;
         int binx,biny;
         double min,max,step;
+        int xstep=0, ystep=0;
         QString frameProp = QString("CCD_FRAME");
-        // Check whether main camera or guide head only
 
+        // Check whether main camera or guide head only
         currentCCD = CCDs.at(ccdNum);
 
         if (CCDCaptureCombo->itemText(ccdNum).right(6) == QString("Guider"))
         {
-            frameProp = QString("GUIDE_FRAME");
+            frameProp = QString("GUIDER_FRAME");
             useGuideHead = true;
             targetChip = currentCCD->getChip(ISD::CCDChip::GUIDE_CCD);
         }
@@ -218,8 +219,35 @@ void Capture::checkCCD(int ccdNum)
             useGuideHead = false;
         }
 
+        if (currentCCD->getMinMaxStep(frameProp, "WIDTH", &min, &max, &step))
+        {
+            if (step == 0)
+                xstep = (int) max * 0.05;
+            else
+                xstep = step;
+
+            frameWIN->setMinimum(min);
+            frameWIN->setMaximum(max);
+            frameWIN->setSingleStep(xstep);
+        }
+
+        if (currentCCD->getMinMaxStep(frameProp, "HEIGHT", &min, &max, &step))
+        {
+            if (step == 0)
+                ystep = (int) max * 0.05;
+            else
+                ystep = step;
+
+            frameHIN->setMinimum(min);
+            frameHIN->setMaximum(max);
+            frameHIN->setSingleStep(ystep);
+        }
+
         if (currentCCD->getMinMaxStep(frameProp, "X", &min, &max, &step))
         {
+            if (step == 0)
+                step = xstep;
+
             frameXIN->setMinimum(min);
             frameXIN->setMaximum(max);
             frameXIN->setSingleStep(step);
@@ -227,24 +255,15 @@ void Capture::checkCCD(int ccdNum)
 
         if (currentCCD->getMinMaxStep(frameProp, "Y", &min, &max, &step))
         {
+            if (step == 0)
+                step = ystep;
+
             frameYIN->setMinimum(min);
             frameYIN->setMaximum(max);
             frameYIN->setSingleStep(step);
         }
 
-        if (currentCCD->getMinMaxStep(frameProp, "WIDTH", &min, &max, &step))
-        {
-            frameWIN->setMinimum(min);
-            frameWIN->setMaximum(max);
-            frameWIN->setSingleStep(step);
-        }
 
-        if (currentCCD->getMinMaxStep(frameProp, "HEIGHT", &min, &max, &step))
-        {
-            frameHIN->setMinimum(min);
-            frameHIN->setMaximum(max);
-            frameHIN->setSingleStep(step);
-        }
 
         if (targetChip->getFrame(&x,&y,&w,&h))
         {
@@ -373,9 +392,12 @@ void Capture::newFITS(IBLOB *bp)
         FITSView *calibrateImage = targetChip->getImage(FITS_CALIBRATE);
         FITSView *currentImage   = targetChip->getImage(FITS_NORMAL);
 
-        FITSImage *image_data = currentImage->getImageData();
+        FITSImage *image_data = NULL;
 
-        if (calibrateImage && currentImage)
+        if (currentImage)
+            image_data = currentImage->getImageData();
+
+        if (image_data && calibrateImage && currentImage)
             image_data->subtract(calibrateImage->getImageData()->getImageBuffer());
     }
 
@@ -412,7 +434,8 @@ void Capture::newFITS(IBLOB *bp)
 
             SequenceJob *job = jobs.at(jobIndex);
 
-            executeJob(job);
+            if (job)
+                executeJob(job);
         }
 
     }
@@ -441,6 +464,9 @@ void Capture::captureImage()
 
     targetChip = activeJob->activeChip;
 
+    if (targetChip == NULL)
+        return;
+
     if (targetChip->setFrame(activeJob->x, activeJob->y, activeJob->w, activeJob->h) == false)
     {
         appendLogText(i18n("Failed to set sub frame."));
@@ -455,7 +481,7 @@ void Capture::captureImage()
 
     }
 
-    if (useGuideHead == false && targetChip->setBinning(activeJob->binX, activeJob->binY) == false)
+    if (targetChip->setBinning(activeJob->binX, activeJob->binY) == false)
     {
         appendLogText(i18n("Failed to set binning."));
 
@@ -478,10 +504,7 @@ void Capture::captureImage()
     }
     else
     {
-
-        if (useGuideHead == false)
-            targetChip->setFrameType(frameTypeCombo->itemText(activeJob->frameType));
-
+        targetChip->setFrameType(frameTypeCombo->itemText(activeJob->frameType));
         targetChip->setCaptureMode(FITS_NORMAL);
         targetChip->setCaptureFilter( (FITSScale) filterCombo->currentIndex());
         appendLogText(i18n("Capturing image..."));
